summaryrefslogtreecommitdiffstats
path: root/kalarm/find.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-04-13 00:46:47 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-04-13 00:46:47 +0000
commit67e29a054cfcb1b0d2fe6b0a316cf6b3eec087b7 (patch)
tree5f52a9eada2e9f3654fc327d7c14dfef570a6ecb /kalarm/find.h
parent2ee4bf4fd5eff93b2fbef0ff8e8063edffc5da5c (diff)
downloadtdepim-67e29a054cfcb1b0d2fe6b0a316cf6b3eec087b7.tar.gz
tdepim-67e29a054cfcb1b0d2fe6b0a316cf6b3eec087b7.zip
Initial conversion of kdepim to TQt
This will probably require some tweaking before it will build under Qt4, however Qt3 builds are OK. Any alterations this commit makes to kdepim behaviour under Qt3 are unintentional and should be fixed. git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdepim@1227832 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kalarm/find.h')
-rw-r--r--kalarm/find.h7
1 files changed, 4 insertions, 3 deletions
diff --git a/kalarm/find.h b/kalarm/find.h
index 3dba48d9..f7170a29 100644
--- a/kalarm/find.h
+++ b/kalarm/find.h
@@ -33,11 +33,12 @@ class EventListViewBase;
class EventListViewItemBase;
-class Find : public QObject
+class Find : public TQObject
{
Q_OBJECT
+ TQ_OBJECT
public:
- explicit Find(EventListViewBase* parent);
+ explicit Find(EventListViewBase* tqparent);
~Find();
void display();
void findNext(bool forward) { findNext(forward, true); }
@@ -53,7 +54,7 @@ class Find : public QObject
void findNext(bool forward, bool sort, bool checkEnd = false, bool fromCurrent = false);
EventListViewItemBase* nextItem(EventListViewItemBase*, bool forward) const;
- EventListViewBase* mListView; // parent list view
+ EventListViewBase* mListView; // tqparent list view
TQGuardedPtr<KFindDialog> mDialog;
TQCheckBox* mExpired;
TQCheckBox* mLive;